import logging
from laka import Laka
from param import Param
from response import Response



# 返回码定义
SUCCESS = 0                 # 成功
COMMAND_NOT_FOUND = 1       # 未找到命令
INVALID_PARAM = 10          # 参数错误

# 返回码对应的提示信息
RESPONSE_MESSAGE = {
    SUCCESS: "",
    COMMAND_NOT_FOUND: "Command not found.",
    INVALID_PARAM: "Invalid params",
}


class CreateUserParam(Param):
    CommandCode = 101
    
    def __init__(self):
        self.account = None
        self.username = None
    
    def validate(self):
        return True

    @classmethod
    def handler(cls, cmd):
        try:
            param = cls.load_from_cmd(cmd)
        except Exception as e:
            logging.error(e)
            return None, INVALID_PARAM
        user = {"username":param.username, "account":param.account}
        return user, SUCCESS
    

if __name__ == "__main__":
    laka = Laka(redis_host="localhost", redis_port=6379, redis_queue="laka_request", response_message=RESPONSE_MESSAGE)
    for cmd in laka.accept_request():
        data, resp_code = None, COMMAND_NOT_FOUND
        if cmd.code == CreateUserParam.CommandCode:
            data, resp_code = CreateUserParam.handler(cmd)
        laka.response(cmd.request_id, resp_code, data)

    


class Param(object):
    CommandCode = -1
    
    def __init__(self):
        raise NotImplementedError
    
    def validate(self):
        return True
    
    @classmethod
    def load_from_cmd(cls, cmd):
        if cls.CommandCode < 0 or not isinstance(cls.CommandCode, int):
            raise Exception("Invalid CommandCode = {}, CommandCode should be not less than 0, and should be integer".format(cls.CommandCode))
        if cmd.code != cls.CommandCode:
            raise Exception("Invalid code to do this, code = {}".format(cmd.code))
        param = cls()
        keys = param.__dict__.keys()
        for key in keys:
            setattr(param, key, cmd.params.get(key))
        status = param.validate()
        if not status:
            raise Exception("Invalid params.")
        return param


#coding:utf-8

from os import path
from codecs import open
from setuptools import setup

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name = "Laka",
    version = "0.1",
    author = "Gaojian",
    license = "MIT",
    packages = ["laka"],
    author_email = "olivetree123@163.com",
    url = "https://github.com/olivetree123/Laka",
    description = "Micro Service Framework for Python",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    install_requires = [
        "redis",
    ],
)
